//
//  CUView.m
//  SimplePaint
//
//  Created by Ken Anderson on 10/31/12.
//  Copyright (c) 2012 University of Colorado. All rights reserved.
//

#import "CUView.h"

#import "CURect.h"

@interface CUView ()

@property (nonatomic, strong) NSMutableArray *rects;
@property (nonatomic) CGRect motionRect;
@property (nonatomic) CGPoint anchorPoint;

@end

@implementation CUView

- (void)awakeFromNib {
    
    self.anchorPoint = CGPointZero;
    self.motionRect = CGRectZero;
    
    self.rects = [[NSMutableArray alloc] init];
}

- (void)drawRect:(CGRect)rect {

    CGContextRef context = UIGraphicsGetCurrentContext();
    CGContextSetLineWidth(context, 2.0);
    
    for (CURect *rect in self.rects) {
        [rect.color setFill];
        CGContextAddRect(context, rect.rect);
        CGContextFillPath(context);
    }
    
    if (!CGRectIsNull(self.motionRect)) {
        [self.currentColor setFill];
        CGContextAddRect(context, self.motionRect);
        CGContextFillPath(context);
    }

}

- (CGRect) makeRectWithOrigin:(CGPoint) p1 andPoint:(CGPoint) p2 {
    return CGRectMake(p1.x, p1.y,  fabs(p2.x-p1.x), fabs(p2.y-p1.y));
}

- (void) clearAll {
    [self.rects removeAllObjects];
    [[self subviews]
     makeObjectsPerformSelector:@selector(removeFromSuperview)];

    [self setNeedsDisplay];
    
    self.anchorPoint = CGPointZero;
    self.motionRect = CGRectZero;

}

- (void) touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event {
    UITouch *t = [touches anyObject];
    
    if ([t tapCount] > 1) {
        [self clearAll];
        return;
    }
    
    CGPoint loc = [t locationInView:self];
    self.motionRect = CGRectMake(loc.x, loc.y, 0, 0);
    self.anchorPoint = loc;
}

- (void) updateMotionRectWithLocation:(CGPoint) loc {
    if ((loc.x > self.anchorPoint.x) && (loc.y > self.anchorPoint.y)) {
        self.motionRect = [self makeRectWithOrigin:self.anchorPoint andPoint:loc];
        [self setNeedsDisplay];
    }
    
    if ((loc.x > self.anchorPoint.x) && (loc.y < self.anchorPoint.y)) {
        CGPoint origin = CGPointMake(self.anchorPoint.x, loc.y);
        CGPoint point  = CGPointMake(loc.x, self.anchorPoint.y);
        self.motionRect = [self makeRectWithOrigin:origin andPoint:point];
        [self setNeedsDisplay];
    }
    
    if ((loc.x < self.anchorPoint.x) && (loc.y > self.anchorPoint.y)) {
        CGPoint origin = CGPointMake(loc.x, self.anchorPoint.y);
        CGPoint point  = CGPointMake(self.anchorPoint.x, loc.y);
        self.motionRect = [self makeRectWithOrigin:origin andPoint:point];
        [self setNeedsDisplay];
    }
    
    if ((loc.x < self.anchorPoint.x) && (loc.y < self.anchorPoint.y)) {
        CGPoint origin = loc;
        CGPoint point = self.anchorPoint;
        self.motionRect = [self makeRectWithOrigin:origin andPoint:point];
        [self setNeedsDisplay];
    }

}

- (void) touchesMoved:(NSSet *)touches withEvent:(UIEvent *)event {
    UITouch *t = [touches anyObject];
    CGPoint loc = [t locationInView:self];
    [self updateMotionRectWithLocation:loc];
    [self setNeedsDisplay];
}

- (void)touchesEnded:(NSSet *)touches withEvent:(UIEvent *)event {
    UITouch *t = [touches anyObject];
    
    if ([t tapCount] > 1) {
        return;
    }

    CGPoint loc = [t locationInView:self];
    [self updateMotionRectWithLocation:loc];

    CURect *rect = [[CURect alloc] init];
    rect.rect = self.motionRect;
    rect.color = self.currentColor;

    [self.rects addObject:rect];
    [self setNeedsDisplay];
    
    self.anchorPoint = CGPointZero;
    self.motionRect = CGRectZero;
}

@end
