//
//  CUViewController.m
//  SimplePaint
//
//  Created by Ken Anderson on 10/31/12.
//  Copyright (c) 2012 University of Colorado. All rights reserved.
//

#import "CUViewController.h"

#import "CUView.h"

NSString * const SimplePaintColorPrefKey = @"SimplePaintColorPrefKey";

@interface CUViewController ()

@property (weak, nonatomic) IBOutlet UISegmentedControl *colorControl;
@property (weak, nonatomic) IBOutlet CUView *myView;

@end

@implementation CUViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.myView.currentColor = [UIColor blackColor];
    NSInteger selectedColor = [[NSUserDefaults standardUserDefaults] integerForKey:SimplePaintColorPrefKey];
    self.colorControl.selectedSegmentIndex = selectedColor;
    [self handleColorChange:self.colorControl];
}

- (IBAction)handleColorChange:(UISegmentedControl *)sender {
    switch (sender.selectedSegmentIndex) {
        case 0:
            self.myView.currentColor = [UIColor blackColor];
            break;
        case 1:
            self.myView.currentColor = [UIColor redColor];
            break;
        case 2:
            self.myView.currentColor = [UIColor greenColor];
            break;
        case 3:
            self.myView.currentColor = [UIColor blueColor];
            break;
        default:
            NSLog(@"Unexpected Segment Selected : %d", sender.selectedSegmentIndex);
            break;
    }
    [[NSUserDefaults standardUserDefaults] setInteger:sender.selectedSegmentIndex forKey:SimplePaintColorPrefKey];
}

- (IBAction)handleLongPress:(UILongPressGestureRecognizer *)sender {
    if (sender.state == UIGestureRecognizerStateBegan) {
        CGPoint loc = [sender locationInView:self.myView];
        UIImageView *icon = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"Star.tif"]];
        icon.frame = CGRectMake(0, 0, 20, 20);
        icon.center = loc;
        [self.myView addSubview:icon];
    }
}

- (IBAction)handleAnimate:(UIBarButtonItem *)sender {
    NSArray *subviews = [self.myView subviews];
    for (UIView *view in subviews) {
        CGRect bounds = self.myView.bounds;
        NSUInteger randomX = arc4random_uniform((uint32_t)bounds.size.width);
        NSUInteger randomY = arc4random_uniform((uint32_t)bounds.size.height);
        if (randomX < 20) {
            randomX = 20;
        }
        if (randomY < 20) {
            randomY = 20;
        }
        if (randomX > bounds.size.width - 20) {
            randomX = bounds.size.width - 20;
        }
        if (randomY > bounds.size.height - 20) {
            randomY = bounds.size.height - 20;
        }
        [UIView animateWithDuration:1.0 animations:^{
            view.center = CGPointMake(randomX, randomY);
        }];
    }
}

- (IBAction)handleFade:(UIBarButtonItem *)sender {
    NSArray *subviews = [self.myView subviews];
    for (UIView *view in subviews) {
        [UIView animateWithDuration:1.0
                         animations:^{view.alpha = 0.0;}
                         completion:^(BOOL finished){
                             [view removeFromSuperview]; }];
    }

}

@end
