//
//  ContactTableViewController.m
//  TheSocial
//
//  Created by Ken Anderson on 10/19/12.
//  Copyright (c) 2012 University of Colorado. All rights reserved.
//

#import "ContactTableViewController.h"

#import "ContactInfo.h"
#import "ContactDetailViewController.h"

@interface ContactTableViewController ()

@property (nonatomic, strong) NSMutableArray *contacts;

- (NSString *) archivePath;
- (void) saveChanges;
- (void) loadContacts;

@end

@implementation ContactTableViewController

- (NSString *) archivePath {
    NSArray *directories = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *directory = [directories objectAtIndex:0];
    return [directory stringByAppendingPathComponent:@"contacts.bin"];
}

- (void)saveChanges {
    [NSKeyedArchiver archiveRootObject:self.contacts toFile:[self archivePath]];
}

- (void)loadContacts {
    if (!self.contacts) {
        self.contacts = [NSKeyedUnarchiver unarchiveObjectWithFile:[self archivePath]];
    }
    
    if (!self.contacts) {
        self.contacts = [[NSMutableArray alloc] init];
    }
    
    if (self.contacts.count == 0) {
        ContactInfo *info = [[ContactInfo alloc] init];
        info.name = @"Steve Martin";
        info.twitter = @"SteveMartinToGo";
        info.facebook = @"http://www.facebook.com/SteveMartinofficial";
        info.email = @"Steve.Martin@example.com";
        
        [self.contacts addObject:info];
        
        info = [[ContactInfo alloc] init];
        info.name = @"Wierd Al Yankovich";
        info.twitter = @"alyankovic";
        info.facebook = @"https://www.facebook.com/weirdal";
        info.email = @"Wierd.Al@example.com";
        
        [self.contacts addObject:info];
    }
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [self loadContacts];
 
    self.navigationItem.leftBarButtonItem = self.editButtonItem;
    
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [self.contacts count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];

    ContactInfo *info = [self.contacts objectAtIndex:indexPath.row];

    cell.textLabel.text = info.name;
    cell.detailTextLabel.text = info.email;
    
    return cell;
}

- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        [self.contacts removeObjectAtIndex:indexPath.row];
        [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:YES];
        [self saveChanges];
    }
}

- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)source toIndexPath:(NSIndexPath *)destination {
    ContactInfo* info = [self.contacts objectAtIndex:source.row];
    [self.contacts removeObjectAtIndex:source.row];
    [self.contacts insertObject:info atIndex:destination.row];
    [self saveChanges];
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    
    ContactDetailViewController *vc = (ContactDetailViewController *)segue.destinationViewController;

    if ([segue.identifier isEqualToString:@"Show Details"]) {
        
        NSIndexPath *index = [self.tableView indexPathForCell:sender];
        
        ContactInfo *info = [self.contacts objectAtIndex:index.row];
        
        vc.info = info;
    }
    
    vc.table = self;

}

- (void)contactUpdated {
    [self saveChanges];
    [self.tableView reloadData];
}

- (void)addContact:(ContactInfo *)info {
    [self.contacts addObject:info];
}

@end
